@@ -219,7 +219,7 @@ class Find:
         query_compiled = self.query.compile()
         data = await self.__then(query_compiled)
         total_pages = data['total_pages']
-        for i in range(total_pages):
+        for i in range(total_pages+1):
             query_aux = copy.deepcopy(query_compiled)
             query_aux['page'] = (i + 1)
             queries.append(self.__then(query_aux))
@@ -553,7 +553,20 @@ class WorkflowQuery:
         self.sbx_workflow = sbx_workflow
         self.url = self.sbx_workflow.urls['api'] + self.sbx_workflow.environment['domain'] + self.sbx_workflow.urls['list_process_execution']
 
+    def __chunk_it(self, seq, num):
+        avg = len(seq) / float(num)
+        out = []
+        last = 0.0
+
+        while last < len(seq):
+            out.append(asyncio.gather(*seq[int(last):int(last + avg)]))
+            last += avg
+
+        return out
+
     async def then(self, params):
+        print(self.sbx_workflow.p(self.url))
+        print(params)
         async with aiohttp.ClientSession() as session:
             async with session.get(
                     self.sbx_workflow.p(self.url), params=params,
@@ -566,10 +579,11 @@ class WorkflowQuery:
         params['page'] = 0
         queries = []
         data = await self.then(params)
+        print(data)
         total_pages = math.ceil(data['totalCount']/page_size)
         for i in range(total_pages):
             params_aux = copy.deepcopy(params)
-            params_aux['page'] = (i + 1)
+            params_aux['page'] = i
             queries.append(self.then(params_aux))
         futures = self.__chunk_it(queries, min(max_in_parallel, len(queries)))
         results = await asyncio.gather(*[futures[i] for i in range(len(futures))])
